@@ -2,21 +2,21 @@
 Core abstractions such as pipes, options and results.
 """
 
-from . import aio, option, result
+from . import aiotools, option, result
 from .builder import Builder
 from .compose import compose
 from .curry import curried
 from .error import EffectError, failwith
 from .fn import TailCall, recursive, recursive_async
 from .mailbox import AsyncReplyChannel, MailboxProcessor
-from .match import Match, Matchable, match
-from .misc import flip, identity
+from .match import Matchable, Matcher, match
+from .misc import flip, fst, identity, snd
 from .option import Nothing, Nothing_, Option, Some
 from .pipe import pipe, pipe2, pipe3
 from .result import Error, Ok, Result
 
 __all__ = [
-    "aio",
+    "aiotools",
     "AsyncReplyChannel",
     "Builder",
     "compose",
@@ -25,11 +25,12 @@ __all__ = [
     "Error",
     "failwith",
     "flip",
+    "fst",
     "identity",
     "MailboxProcessor",
     "match",
-    "Match",
-    "Matching",
+    "Matcher",
+    "Matchable",
     "Nothing",
     "Nothing_",
     "Ok",
@@ -42,6 +43,7 @@ __all__ = [
     "recursive_async",
     "result",
     "Result",
+    "snd",
     "Some",
     "TailCall",
 ]
